<?php
/*
	Plugin Name: WP Gift Machine
	Description: Helps you build your email list automatically using a unique gift icon popup that has never been seen before. A fun, smart and unobtrusive way to build your list.
	Author: Ankur Shukla
	Version: 1.14
	Author URI: https://www.ankurshukla.com
*/

defined( 'ABSPATH' ) or die( 'Nope, not accessing this' );

define( 'GIFTMACHINE_VERSION', '1.14' );
define( 'GIFTMACHINE_PLUGIN_NAME', dirname( plugin_basename( __FILE__ ) ) );
define( 'GIFTMACHINE_DIR', plugin_dir_path( __FILE__ ) );
define( 'GIFTMACHINE_URL', plugins_url( GIFTMACHINE_PLUGIN_NAME ) );

require GIFTMACHINE_DIR.'/lib/common.php';
require GIFTMACHINE_DIR.'/lib/stats.php';
require GIFTMACHINE_DIR.'/lib/jacker.php';
require GIFTMACHINE_DIR.'/lib/saas.php';
if( is_admin( ) )
    require GIFTMACHINE_DIR.'/lib/styles/dashboard.php';

if( giftmachine_is_pro() )
	require GIFTMACHINE_DIR.'/lib/autoresponders.php';

	if ( !class_exists( 'GiftMachinePRO' ) ) {
		class GiftMachinePRO {
			protected $plugins_url = '';
			protected $plugins_path = '';
			protected $type = 'gifts-pro';
			protected $table = 'gift_machine_pro';

			public function __construct() {
				add_action('init', array($this, 'create_gifttype'));
				add_action('add_meta_boxes', array($this, 'gift_meta_boxes'));
				add_action('admin_print_scripts', array($this, 'register_admin_script') );
				add_action( 'wp_enqueue_scripts', array($this, 'frontend_scripts' ) );
				add_action('save_post', array($this, 'save_gifts'));
				add_action('wp_footer', array($this, 'show_gift'));
				add_action("admin_init", array($this, 'check_download'));
        		add_action('admin_menu', array($this, 'custom_menu') );

				add_action('wp_ajax_save_gift_form', array($this, 'save_gift_form'));
				add_action('wp_ajax_nopriv_save_gift_form', array($this, 'save_gift_form'));
				add_action('wp_ajax_upload_svg', array($this, 'upload_svg'));
				add_action('wp_ajax_nopriv_upload_svg', array($this, 'upload_svg'));
    			add_action( 'wp_ajax_giftmachine_refresh_autoresponder', 'giftmachine_refresh_autoresponder' );
    			add_action( 'wp_ajax_giftmachine_og_tags', 'giftmachine_get_og_tags' );

				add_action('manage_'.$this->type.'_posts_custom_column', array($this, 'leads_column'), 10, 2);
				add_action('admin_enqueue_scripts', array($this, 'add_color_picker') );

				add_filter('manage_'.$this->type.'_posts_columns', array($this,'add_column') );

				$this->plugins_url = plugins_url('', __FILE__);
				$this->plugins_path = plugin_dir_path(__FILE__);
				register_activation_hook( __FILE__, [$this, 'dbOperation']);
			}

			public function create_gifttype() {
			    $labels = array(
			        'name'                => _x( 'Gift Machine'.giftmachine_append_pro(), 'GiftMachinePRO' ),
			        'singular_name'       => _x( 'Gift', 'Gift' ),
			        'menu_name'           => __( 'Gift Machine'.giftmachine_append_pro() ),
			        'parent_item_colon'   => __( 'Parent Gift' ),
			        'all_items'           => __( 'All Gifts', 'twentythirteen' ),
			        'view_item'           => __( 'View Gift', 'twentythirteen' ),
			        'add_new_item'        => __( 'Add New Gift', 'twentythirteen' ),
			        'add_new'             => __( 'Add New', 'twentythirteen' ),
			        'edit_item'           => __( 'Edit Gift', 'twentythirteen' ),
			        'update_item'         => __( 'Update Gift', 'twentythirteen' ),
			        'search_items'        => __( 'Search Gift', 'twentythirteen' ),
			        'not_found'           => __( 'No Gift Slots Found.', 'twentythirteen' ),
			        'not_found_in_trash'  => __( 'Not found in Trash', 'twentythirteen' ),
			    );

			// Set other options for Custom Post Type

			    $args = array(
			        'label'               => __( 'gifts', 'twentythirteen' ),
			        'description'         => __( 'Gifts for customers', 'twentythirteen' ),
			        'labels'              => $labels,
			        'supports'            => array( 'title' ),
			        'taxonomies'          => array( 'genres' ),
			        'hierarchical'        => false,
			        'public'              => false,
			        'show_ui'             => true,
			        'show_in_menu'        => true,
			        'show_in_nav_menus'   => true,
			        'show_in_admin_bar'   => true,
			        'menu_position'       => 5,
			        'can_export'          => true,
			        'has_archive'         => true,
			        'exclude_from_search' => false,
			        'publicly_queryable'  => false,
			        'capability_type'     => 'page',
			        /*'capabilities' => array(
			            'create_posts' => 'do_not_allow'
			        )*/
			    );

			    // Registering your Custom Post Type
			    register_post_type( $this->type, $args );
			}

			public function custom_menu() {
				include GIFTMACHINE_DIR.'/lib/styles/styles.php';
				// ask28_delete_license();
				$style28 = ask36_lic_status();
				// var_dump($style28);
				if( $style28 ) {
					add_submenu_page("edit.php?post_type=" . $this->type, "Stats", "Stats", "manage_options", "gmstats", ($style28 ? array($this, "stats") : 'ask36_settings') );
					if( giftmachine_is_pro() )
						add_submenu_page( "edit.php?post_type=" . $this->type, "Autoresponders", "Autoresponders", "manage_options", "gmautoresponders", array($this, "autoresponders"));
					if( giftmachine_is_jacker() )
						add_submenu_page( "edit.php?post_type=" . $this->type, "Jacker", "Jacker", "manage_options", "gmjacker", array($this, "jacker"));
					if( giftmachine_is_saas() )
						add_submenu_page( "edit.php?post_type=" . $this->type, "External Sites", "External Sites", "manage_options", "gmsaas", array($this, "saas"));
					add_submenu_page("edit.php?post_type=" . $this->type, "Leads", "Leads", "manage_options", "view-leads", array($this, "listing"));
					add_submenu_page("edit.php?post_type=" . $this->type, "Help", "Help", "manage_options", "help", array($this, "help"));
				}
				else {
					$page1 = add_menu_page( 'Gift Machine'.giftmachine_append_pro(), 'Gift Machine'.giftmachine_append_pro(), 'manage_options', 'gift-machine', 'ask36_settings', false, 9 );
					add_submenu_page("gift-machine", "Help", "Help", "manage_options", "help", array($this, "help"));
					remove_menu_page( 'edit.php?post_type='. $this->type );
				}
			}

			public function help() {
				echo '
				<div class="wrap">
					<h1>Looking for Help?</h1>
					<h3 class="splash-head">Watch These Training Videos</h3>
					<center>
					         <p><h4 style="font-size:1.2em">Video 1 - Main Plugin + SAAS Addon Installation</h4><br>
					            <iframe src="https://player.vimeo.com/video/516646429?title=0&byline=0&portrait=0" width="800" height="450" frameborder="0" allow="autoplay; fullscreen" allowfullscreen></iframe>
					        </p>
					        <br>
					          <p><h4 style="font-size:1.2em">Video 2 - PRO Plugin Installation and Features</h4><br>
					            <iframe src="https://player.vimeo.com/video/516645789?title=0&byline=0&portrait=0" width="800" height="450" frameborder="0" allow="autoplay; fullscreen" allowfullscreen></iframe>
					        </p>';
					if( !giftmachine_is_pro() ) {
						echo '<a href="https://kudosinteractive.clickfunnels.com/oto1-pro1608585489658" target="_blank" class="button button-primary">Get the Pro Version Here</a><br/>';
					}

	echo '					        <br>
					          <p><h4 style="font-size:1.2em">Video 3 - Jacker addon Installation and Features</h4><br>
					            <iframe src="https://player.vimeo.com/video/516646860?title=0&byline=0&portrait=0" width="800" height="450" frameborder="0" allow="autoplay; fullscreen" allowfullscreen></iframe>
					        </p>';
					        if( !giftmachine_is_jacker() ) {
					        	echo '<a href="https://kudosinteractive.clickfunnels.com/oto1-pro1613984452297" class="button button-primary" target="_blank" >Get the Jacker Addon Here</a><br/>';
					        }
					        echo '<p class="splash-subhead">
					         <br><br>
					        If you face any issue with the plugin, please submit a ticket below...
					        </p>
					        <p>
					            <a href="http://customerhelpdesk.in/index.php?a=add&catid=96" class="button button-primary" target="_blank">Submit a Ticket</a>
					        </p>
					    </center>
				</div>
				';
			}

			public function stats() {
				giftmachine_page_handler_stats();
			}

			public function autoresponders() {
				giftmachine_screen_autoresponders();
			}

			public function jacker() {
				giftmachine_screen_jacker();
			}

			public function saas() {
				giftmachine_screen_saas();
			}

			public function listing() {
				global $wpdb;
				if( isset( $_GET['gid'] ) )  {
					$gift_id = intval( $_GET['gid'] );
					$leads = $wpdb->get_results("SELECT * FROM ". $wpdb->prefix.$this->table." WHERE gid = " . $_GET['gid']);
					$ptitle = get_the_title($_GET['gid']);
				}
				else {
					$gift_id = 0;
					$leads = $wpdb->get_results("SELECT * FROM ". $wpdb->prefix.$this->table );
					$ptitle = 'All Gifts';
				}

				echo '
				<div class="wrap">
					<h1 class="wp-heading-inline">Collected Leads - '.$ptitle.'</h1>
					<hr class="wp-header-end">
					<br><br>
					<ul class="subsubsub"></ul>
					<table class="wp-list-table widefat fixed striped table-view-list posts">
						<thead>
							<tr>
								<th style="width: 10%;"</th>
								<th style="width: 30%;">Name</th>
								<th style="width: 30%;">Email</th>
								<th style="width: 30%;">Phone</th>
							</tr>
						</thead>
						<tbody>
				';
				if (count($leads) > 0) {
					$i = 1;
					foreach ($leads as $lead) {
					    echo '
					    <tr>
					    	<td>'.$i++.'</td>
					    	<td>'.$lead->name.'</td>
					    	<td>'.$lead->email.'</td>
					    	<td>'.$lead->phone.'</td>
					    </tr>
					    ';
					}
				}
				else {
					echo '<tr><td colspan="4" style="text-align: center;">No Leads Found!</td></tr>';
				}
				echo "
						</tbody>
					</table>
				</div>
				";
			}

			public function dbOperation() {
				global $wpdb;

				$table_name = $wpdb->prefix . $this->table;
				$charset_collate = $wpdb->get_charset_collate();

				$sql = "CREATE TABLE IF NOT EXISTS $table_name (
				  id int(11) NOT NULL AUTO_INCREMENT,
				  pid int(11) NOT NULL,
				  gid int(11) NOT NULL,
				  name varchar(255) NOT NULL,
				  email varchar(255) DEFAULT '',
				  phone varchar(255) DEFAULT '',
				  time datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
				  PRIMARY KEY (id)
				) $charset_collate;";
				require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

				dbDelta( $sql );
			}

			public function add_report_link($actions, $post) {
				if ( $post->post_type == $this->type) {
					$url = get_edit_post_link($post->ID) . '&source=download';
					$actions['leads'] = '<a href="'.$url.'"><i class="fas fa-download"></i> Download Leads</a>';
				}
				return $actions;
			}

			public function check_download() {
				if (isset( $_REQUEST['source'] ) && ( $_REQUEST['source'] == 'download') ) {
					global $wpdb;
					$gift_id = $_REQUEST['post'];
					$leads = $wpdb->get_results("SELECT * FROM ". $wpdb->prefix.$this->table." WHERE gid = $gift_id");
					$f = fopen('leads-'.$gift_id.'2.csv', 'w');
					$data = "id, Post ID, Gift ID, Name, Email, Phone, Date" . "\n";
					foreach ($leads as $lead) {
					    $data .= "$lead->id, $lead->pid, $lead->gid, $lead->name, $lead->email, $lead->phone, $lead->time" . "\n";
					}
					fclose($f);
					header('Content-Type: application/csv');
					header('Content-Disposition: attachment; filename="leads-'.$gift_id.'.csv";');
					echo $data;
					exit;
				}

				global $menu;
				if( !empty( $menu ) ) {
				    foreach($menu as $key => $value) {
				        if('Gift Machine PRO' == $value[0]) {
				            $menu[$key][4] .= " custom-class-1";
				        }
				    }
			    }
			}

			public function add_column($columns){
				$columns['leads'] = __( 'Total Leads' );
				$columns['view_leads'] = __( 'View Leads' );
				$columns['download_leads'] = __( 'Download Leads' );
				return $columns;
			}

			public function leads_column($column, $post_id) {
				global $wpdb;
				$table = $wpdb->prefix . $this->table;

				if ($column == "leads") {
					$rowcount = $wpdb->get_var("SELECT COUNT(*) FROM $table WHERE gid = $post_id");
					echo $rowcount;
				}

				if ($column == "view_leads") {
					echo '<a class="button button-primary button-large" href="edit.php?post_type='.$this->type.'&page=view-leads&gid='.$post_id.'"><i class="fas fa-envelope"></i> View Leads</a>';
				}

				if ($column == "download_leads") {
					$url = get_edit_post_link($post_id) . '&source=download';
					echo '<a class="button button-large" href="'.$url.'"><i class="fas fa-download"></i> Download Leads</a>';
				}
			}

			public function show_gift() {
				global $post;
				$gift_id = get_post_meta( $post->ID, 'gift_posts', true );

				if ( $gift_id == '' || ( empty( $gift_id ) ) ) {
					$cc_args = array();
					$done = 0;
					if ( is_home() || is_front_page() ) {
						$done = 1;
						$cc_args = array(
						    'posts_per_page' => 1,
						    'post_type' => $this->type,
						    'meta_query' => array(
						    	array(
						    		'key' => 'gift_popup_visibility',
						    		'value' => 'homepage',
						    		'compare' => 'LIKE'
						    	)
						    )
						);

					}
					if ( !$done && is_category() ) {
						$done = 1;
						$cc_args = array(
						    'posts_per_page'   => 1,
						    'post_type'        => $this->type,
						    'meta_key'         => 'gift_popup_visibility',
						    'meta_query' => array(
						    	array(
						    		'key' => 'gift_popup_visibility',
						    		'value' => 'category',
						    		'compare' => 'LIKE'
						    	)
						    )
						);
					}
					if ( !$done && is_page() ) {
						$done = 1;
						$cc_args = array(
						    'posts_per_page'   => 1,
						    'post_type'        => $this->type,
						    'meta_query' => array(
						    	array(
						    		'key' => 'gift_popup_visibility',
						    		'value' => 'pages',
						    		'compare' => 'LIKE'
						    	)
						    )
						);
					}
					if ( !$done && is_single( $post->ID ) ) {
						$done = 1;
						$cc_args = array(
						    'posts_per_page'   => 1,
						    'post_type'        => $this->type,
						    'meta_query' => array(
						    	array(
						    		'key' => 'gift_popup_visibility',
						    		'value' => 'posts',
						    		'compare' => 'LIKE'
						    	)
						    )
						);
					}



					if ( count( $cc_args ) > 0) {
						$cc_query = new WP_Query( $cc_args );
						$gift = $cc_query->posts;
						$gift_id = count($gift) > 0 ? $gift[0]->ID : '';
					}

					if ( $gift_id == '' ) {
						$cc_args = array(
						    'posts_per_page'   => 1,
						    'post_type'        => $this->type,
						    'meta_query' => array(
						    	array(
						    		'key' => 'gift_popup_visibility',
						    		'value' => 'entire',
						    		'compare' => 'LIKE'
						    	)
						    )
						);
						$cc_query = new WP_Query( $cc_args );
						$gift = $cc_query->posts;
						$gift_id = count($gift) > 0 ? $gift[0]->ID : '';
					}
				}


				if ( $gift_id == 'disable' ) {
					return;
				}
				else if ( $gift_id > 0 ) {
					if( giftmachine_is_pro() && wp_is_mobile() ) {
						// check if maybe we set hide on mobile
						$hide_mobile = get_post_meta( $gift_id, '_hide_mobile', true );
						if( $hide_mobile == 1 )
							return;
					}
					else if( giftmachine_is_pro() ) {
						// check if we are outside the date
						$start = trim( get_post_meta( $gift_id, '_gift_start', true ) );
						$end = trim( get_post_meta( $gift_id, '_gift_end', true ) );
						if( !empty( $start ) || !empty( $end ) ) {
							if( !empty( $start ) ) {
								if( new DateTime() < new DateTime($start ) )
									return;
							}
							if( !empty( $end ) ) {
								if( new DateTime() > new DateTime($end ) )
									return;
							}
						}
					}
					$metas = get_post_custom($gift_id);
					$icon = $this->plugins_url.'/images/'.$metas['gift_image_option'][0];
					$fields = explode(",", get_post_meta($gift_id, 'gift_popup_fields', true));
					$btnBgColor = get_post_meta($gift_id, 'gift_popup_button_bg', true);
					$btnTxtColor = get_post_meta($gift_id, 'gift_popup_button_txt', true);
					$btn_txt = get_post_meta($gift_id, 'gift_popup_button', true);
					if( empty( $btn_txt ) )
						$btn_txt = 'Click here';
					if( empty( $btnBgColor ) )
						$btnBgColor = '#666666';
					if( empty( $btnTxtColor ) )
						$btnTxtColor = '#ffffff';

					echo '<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
						<div id="myModal1" class="gmmodal">
							<div class="gmmodal-content">
								<div class="gmmodal-header" style="background: '.$metas['gift_popup_title_bg'][0].'">
									<span class="gmclose">&times;</span>
									<h2>'.$metas['gift_popup_title'][0].'</h2>
								</div>
								<div class="gmmodal-body">
									<p>'.$metas['gift_popup_content'][0].'</p>
									<div class="gift_form">
										<input type="hidden" name="pid" id="pid" value="'.$post->ID.'" />
										<input type="hidden" name="gid" id="gid" value="'.$gift_id.'" />
										<table class="form-table"  id="gift-table">
											<tbody>';
									if (in_array("name", $fields)) {
										echo'	<tr>
													<th scope="row"><label>Name</label></th><td>
														<input type="text" name="gift_full_name" class="regular-text gm-input" id="gift_full_name" />
													</td>
												</tr>';
									}
									if (in_array("email", $fields)) {
										echo'	<tr>
													<th scope="row"><label>Email</label></th><td>
														<input type="text" name="gift_email" class="regular-text gm-input" id="gift_email" />
													</td>
												</tr>';
									}
									if (in_array("phone", $fields)) {
										echo'	<tr>
													<th scope="row"><label>Phone</label></th><td>
														<input type="text" name="gift_phone" class="regular-text gm-input" id="gift_phone" />
													</td>
												</tr>';
									}
								echo '</tbody>
										</table>
										<div class="text-center"><a class="btngm" id="giftSubmitInfo" href="javascript: void(0);" style="background: '.$btnBgColor.';color: '.$btnTxtColor.'">'.$btn_txt.'</a></div>
										<div class="clearbb"> </div>
									</div>
								</div>
								<div class="clearbb"> </div>
							</div>
						</div>
						<div id="giftIcon"><img class="'.$metas['gift_image_animation'][0].'" src="'.$icon.'" style="width: 100%;" /></div>
					';
					echo '<script>document.addEventListener("DOMContentLoaded", function(event) { showGift('.$gift_id.', "'.$metas['gift_popup_url'][0].'", '.$metas['gift_popup_sec'][0].');});</script>';
				}
			}

			/* Insert into Db*/
			public function save_gift_form() {
				global $wpdb;
				$table_name = $wpdb->prefix . $this->table;
				unset( $_REQUEST['action'] );
				$jacker_id = isset( $_REQUEST['jacker_id'] ) ? intval( $_REQUEST['jacker_id'] ) : 0;
				// if( isset( $_REQUEST['jacker_id'] ))
					// unset( $_REQUEST['jacker_id'] );
				$gid = isset( $_REQUEST[ 'gid'] ) ? intval( $_REQUEST[ 'gid'] ) : 0;
				$pid = isset( $_REQUEST[ 'pid'] ) ? intval( $_REQUEST[ 'pid'] ) : 0;
				$email = isset( $_REQUEST[ 'email'] ) ? trim( $_REQUEST[ 'email'] ) : '';
				$name = isset( $_REQUEST[ 'name'] ) ? trim( $_REQUEST[ 'name'] ) : '';
				$phone = isset( $_REQUEST[ 'phone'] ) ? trim( $_REQUEST[ 'phone'] ) : '';
				$sql = "INSERT INTO $table_name (gid, pid, email, name, phone) VALUES ($gid, $pid, '$email', '$name', '$phone')";
				$wpdb->query( $sql );
				// $wpdb->insert( $table_name, $_REQUEST );
				// maybe autoresponder?
				if( giftmachine_is_pro() ) {
					$gift_id = isset( $_POST['gid'] ) ? intval( $_POST['gid'] ) : 0;
					if( $gift_id ) {
						$ar = get_post_meta( $gift_id, '_gift_autoresponder', true );
						$list = get_post_meta( $gift_id, '_gift_list', true );
						if( !empty( $ar ) && !empty( $list ) ) {
							$name = isset( $_POST['name'] ) ? trim( $_POST['name'] ) : '';
							$email = isset( $_POST['email'] ) ? trim( $_POST['email'] ) : '';
							giftmachine_signup_customer_autoresponder( $ar, $list, $email, $name );
						}
					}
				}
				if( giftmachine_is_jacker() ) {
					giftmachine_add_conversion( $jacker_id );
				}
				exit();
			}

			public function save_gifts($post_id) {
				if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return;

				global $post;
			    if ($post->post_type != $this->type){
			    	update_post_meta($post_id, 'gift_posts', $_POST['gift_posts']);
			        return true;
			    }

			    if (!isset($_POST['gift_popup_fields']))
			    	$_POST['gift_popup_fields'] = array();

			    if (!isset($_POST['gift_popup_visibility']))
			    	$_POST['gift_popup_visibility'] = array();

			    update_post_meta($post_id, 'gift_popup_title', $_POST['gift_popup_title']);
			    update_post_meta($post_id, 'gift_popup_content', $_POST['gift_popup_content']);
			    update_post_meta($post_id, 'gift_image_option', $_POST['gift_image_option']);
			    update_post_meta($post_id, 'gift_popup_url', $_POST['gift_popup_url']);
			    update_post_meta($post_id, 'gift_popup_sec', $_POST['gift_popup_sec']);
			    update_post_meta($post_id, 'gift_image_animation', $_POST['gift_image_animation']);
			    update_post_meta($post_id, 'gift_popup_fields', implode(",", $_POST['gift_popup_fields']) );
			    update_post_meta($post_id, 'gift_popup_visibility', implode(",", $_POST['gift_popup_visibility']));
			    update_post_meta($post_id, 'gift_popup_button', $_POST['gift_popup_button']);
			    update_post_meta($post_id, 'gift_popup_title_bg', $_POST['gift_popup_title_bg']);
			    update_post_meta($post_id, 'gift_popup_button_bg', $_POST['gift_popup_button_bg']);
			    update_post_meta($post_id, 'gift_popup_button_txt', $_POST['gift_popup_button_txt']);
			    update_post_meta($post_id, '_hide_mobile', isset( $_POST['gift_hide_mobile'] ) ? 1 : 0 );
			    update_post_meta($post_id, '_gift_autoresponder', isset( $_POST['gm-autoresponder'] ) ? $_POST['gm-autoresponder'] : 0 );
			    update_post_meta($post_id, '_gift_list', isset( $_POST['gm-list'] ) ? $_POST['gm-list'] : 0 );
			    update_post_meta($post_id, '_gift_start', isset( $_POST['gift-start-date'] ) ? trim( $_POST['gift-start-date' ] ) : '' );
			    update_post_meta($post_id, '_gift_end', isset( $_POST['gift-end-date'] ) ? trim( $_POST['gift-end-date' ] ) : '' );
			    return true;
			}

			public function register_admin_script() {
				// if (is_admin()) {
				$screen = get_current_screen();

				if( empty( $screen ) )
					return;
				$screen_id = $screen->id;
				$screens = array( 'edit-gifts-pro', 'gifts-pro', 'gifts-pro_page_gmstats', 'gifts-pro_page_gmautoresponders', 'gifts-pro_page_help', 'gifts-pro_page_gmjacker', 'gifts-pro_page_gmsaas' );
				// var_dump( $screen_id );
				// die();
				if( !in_array( $screen_id, $screens ) )
					return;

					wp_enqueue_script('giftmachine-js', $this->plugins_url . '/scripts/admin.js?t=' . GIFTMACHINE_VERSION, array('jquery', 'wp-color-picker'));
				// }
				// else {
					// wp_enqueue_script('giftmachine-js', $this->plugins_url . '/scripts/main.js?t=' . GIFTMACHINE_VERSION, array('jquery'));
				// }
				$script_vars = array();
				if( giftmachine_is_pro() ) {
				    $aweber_lists = giftmachine_get_aweber_mailing_lists();
				    $getresponse_lists = giftmachine_get_getresponse_mailing_lists();
				    $icontact_lists = giftmachine_get_icontact_mailing_lists();
				    $mailchimp_lists = giftmachine_get_mailchimp_mailing_lists();
				    $ccontact_lists = giftmachine_get_constantcontact_mailing_lists();
				    $sendreach_lists = giftmachine_get_sendreach_mailing_lists();
				    // $sendy_lists = giftmachine_get_sendy_mailing_lists();
				    $activecampaign_lists = giftmachine_get_activecampaign_mailing_lists();
				    $mailit_lists = giftmachine_get_mailit_mailing_lists();
				    $sendlane_lists = giftmachine_get_sendlane_mailing_lists();

				    $script_vars = array(
				        'plugin_url' => GIFTMACHINE_URL,
				        'ajax_url' => admin_url( 'admin-ajax.php' ),
				        'admin_url' => admin_url(),
				        'aweber_lists' => $aweber_lists,
				        'getresponse_lists' => $getresponse_lists,
				        'icontact_lists' => $icontact_lists,
				        'mailchimp_lists' => $mailchimp_lists,
				        'ccontact_lists' => $ccontact_lists,
				        'sendreach_lists' => $sendreach_lists,
				        'mailit_lists' => $mailit_lists,
				        'activecampaign_lists' => $activecampaign_lists,
				        'sendlane_lists' => $sendlane_lists,
				        'admin_url' => admin_url( )
				     );
				}

				wp_localize_script('giftmachine-js', 'gmvars', $script_vars );
				wp_enqueue_style('GiftMachinePRO_style', $this->plugins_url . '/style/admin.css?t=' . GIFTMACHINE_VERSION, false,'1.145','all');
				wp_register_style('giftmachine_fa', 'https://use.fontawesome.com/releases/v5.15.2/css/all.css');
				wp_enqueue_style( 'giftmachine_fa' );

				wp_enqueue_script('jquery-ui-datepicker');
			    wp_register_style('jquery-ui', 'https://ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/themes/base/jquery-ui.css');
			    wp_enqueue_style('jquery-ui');
				wp_enqueue_media( );
			}

			public function frontend_scripts() {
				if( is_admin() )
					return;
				wp_enqueue_script('giftmachine-fe-js', $this->plugins_url . '/scripts/front.js?t=' . GIFTMACHINE_VERSION, array('jquery'));
				wp_localize_script('giftmachine-fe-js', 'vars', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
				wp_enqueue_style('GiftMachinePRO_style', $this->plugins_url . '/style/front.css?t=' . GIFTMACHINE_VERSION, false,'1.145','all');
			}

			public function add_color_picker($hook){
		      if( is_admin() ) {
     		      wp_enqueue_style( 'wp-color-picker' );
			    }
			}

			public function gift_meta_boxes() {
				global $post;

				$types = get_post_types('', 'names');
				unset($types[$this->type]);

				add_meta_box('gift_where', __( 'GiftMachine'.giftmachine_append_pro().' Display' ), array($this, 'gift_meta_box_display'), $types, 'side');
        		add_meta_box('gift_seconds', __( 'Icon Display Seconds' ), array($this, 'gift_meta_box_seconds'), $this->type, 'side');
				add_meta_box('gift_url', __( 'Gift Delivery Page / Thank You Page' ), array($this, 'gift_meta_box_url'), $this->type);
				add_meta_box('gift_icons', __( 'Select Your Unique Gift Icon' ), array($this, 'gift_meta_box_icons'), $this->type);
				add_meta_box('gift_popup', __( 'Popup Window Content' ), array($this, 'gift_meta_box_popup'), $this->type);
				add_meta_box('gift_animation', __('Gift Animation'), array($this, 'gift_meta_boxe_animation'), $this->type, 'side');
				add_meta_box('gift_visibility', __('Gift Visibility Options'), array($this, 'gift_meta_visibility'), $this->type, 'side');
				if( giftmachine_is_pro() ) {
					add_meta_box( 'gift_autoresponder', __('Autoresponder Integration' ), array($this, 'gift_meta_autoresponder'), $this->type, 'side' );
				}
			}

			public function gift_leads($gift) {
				global $wpdb;
				$gift_id = get_post_meta($gift->ID, "gift_posts", true);
				$leads = $wpdb->get_results("SELECT * FROM ". $wpdb->prefix.$this->table." WHERE pid = $gift->ID  AND gid = $gift_id");

				echo '
					<div>
					<table id="leadtable">
						<thead>
							<th>id</th>
							<th>Name</th>
							<th>Email</th>
							<th>Phone</th>
							<th>Date</th>
						</thead>
						<tbody>';
				if (count($leads) > 0) {
					foreach ($leads as $lead) {
						echo '<tr align="center">
								<td>'.$lead->id.'</td>
								<td>'.$lead->name.'</td>
								<td>'.$lead->email.'</td>
								<td>'.$lead->phone.'</td>
								<td>'.$lead->time.'</td>
							</tr>';
					}
				}
				else {
					echo '<tr><td></td><td></td><td>No Leads Found!</td><td></td><td></td></tr>';
				}
				echo '
						</tbody>
					</table>
					</div>
				';
			}

			public function gift_meta_box_display($gift) {
  				$selected = get_post_meta($gift->ID, 'gift_posts', true);
  				$gifts = get_posts( array('numberposts' => -1, 'post_status' => 'any', 'post_type' => $this->type) );
  				echo '<div class="components-base-control">
  						<label class="components-base-control__label">Select Gift which you want to show.</label>';
  				if (count($gifts) > 0) {
  					echo '<select name="gift_posts" class="components-select-control__input" style="padding-right: 0;">';
  					echo '<option value="0" '.($selected == 0 ? "selected=selected" : "").'>Default</option>';
  					echo '<option disabled>------------</option>';
  					echo '<option value="disable" '.($selected == "disable" ? "selected=selected" : "").'>Disable for this page</option>';
  					echo '<option disabled>------------</option>';
  					foreach ($gifts as $g) {
  						echo '<option value="'.$g->ID.'" title="'.$g->post_title.'" '.($selected == $g->ID ? "selected=selected" : "").'>'.$g->post_title.'</option>';
  					}
  					echo '</select>';
  				}
  				else
  					echo '<p>You do not have any gifts created yet!</p>';

  				echo '</div><p> </p><hr>';
			}

			public function gift_meta_box_popup($gift) {
				$text = get_post_meta($gift->ID, 'gift_popup_content', true);
				$title = get_post_meta($gift->ID, 'gift_popup_title', true);
				$fields = explode(",", get_post_meta($gift->ID, 'gift_popup_fields', true));
				$btn_txt = get_post_meta($gift->ID, 'gift_popup_button', true);
				$bgColor = get_post_meta($gift->ID, 'gift_popup_title_bg', true);
				$btnBgColor = get_post_meta($gift->ID, 'gift_popup_button_bg', true);
				$btnTxtColor = get_post_meta($gift->ID, 'gift_popup_button_txt', true);
				if( empty( $btnBgColor ) )
					$btnBgColor = '#666666';
				if( empty( $btnTxtColor ) )
					$btnTxtColor = '#ffffff';

				echo '<p>This is the content of the popup that will appear after someone clicks on the gift icon and you can add the title, button text and popup window content to entice the visitor to give you their details so they can get the gift...</p>';
				echo '
					<table class="form-table">
						<tbody>
							<tr>
								<th scope="row"><label>Window Title</label></th>
								<td><input type="text" name="gift_popup_title" class="regular-text" value="'.$title.'" /></td>
							</tr>
							<tr>
								<th scope="row"><label>Window Background Color</label></th>
								<td><input type="text" name="gift_popup_title_bg" id="btnColor" class="regular-text" value="'.$bgColor.'" /></td>
							</tr>
							<tr>
								<th scope="row"><label>Window Content</label></th>
								<td>';
									wp_editor( htmlspecialchars_decode($text), 'gift_popup_content', array ( "media_buttons" => true, "textarea_rows" => 5 ) );
				echo '			</td>
							</tr>
							<tr>
								<th scope="row"><label>Button Text</label></th>
								<td><input type="text" name="gift_popup_button" class="regular-text" value="'.$btn_txt.'" /></td>
							</tr>
							<tr>
								<th scope="row"><label>Button Background Color</label></th>
								<td><input type="text" name="gift_popup_button_bg" id="btnBgColor" class="regular-text" value="'.$btnBgColor.'" /></td>
							</tr>
							<tr>
								<th scope="row"><label>Button Text Color</label></th>
								<td><input type="text" name="gift_popup_button_txt" id="btnTxtColor" class="regular-text" value="'.$btnTxtColor.'" /></td>
							</tr>
							<tr>
								<th scope="row"><label>Input Fields</label></th>
								<td>
									<div style="float: left; width: 30%;">
										<label>
											<input type="checkbox" name="gift_popup_fields[]" value="name" '.(in_array("name", $fields) ? "checked=checked" : "").'/> Name
										</label>
									</div>
									<div style="float: left; width: 30%;">
										<label>
											<input type="checkbox" name="gift_popup_fields[]" value="email" '.(in_array("email", $fields) ? "checked=checked" : "").' /> Email
										</label>
									</div>
									<div style="float: left; width: 30%;">
										<label>
											<input type="checkbox" name="gift_popup_fields[]" value="phone" '.(in_array("phone", $fields) ? "checked=checked" : "").' /> Phone
										</label>
									</div>
								</td>
							</tr>
						</tbody>
					</table>';

			}

			public function gift_meta_box_icons($gift) {
				$icon = get_post_meta($gift->ID, 'gift_image_option', true);
				$files = array_diff( scandir( $this->plugins_path . '/images' ), array('.', '..') );

				echo '<p>This is the icon that will popup when any visitor lands on your site and helps you build your list.</p>';

				if (count($files) > 0) {
					echo '<div id="upload_images">';
					foreach ($files as $f) {
						$url = $this->plugins_url . '/images/' . $f;
						echo '
							<div style="float: left; width: 20%;">
								<label>
									<input type="radio" name="gift_image_option" value="'.$f.'" '.($icon == $f ? "checked=checked" : "").' />
									<img width="80px" src="'.$url.'" />
								</label>
							</div>
						';
					}
					echo '</div>';
				}
				echo '<div style="clear: both;""> </div>';
				if( giftmachine_is_pro() ) {
					echo '
						<br /><br />
						<table class="form-table">
							<tr>
								<th scope="row"><label>Upload Icon</label></th>
								<td><input type="file" name="upload_svg" class="regular-text" id="upload_svg" onchange="uploadImg();" /></td>
							</tr>
						</table>
					';
				}
			}

			public function upload_svg() {
				if (isset($_FILES) && isset($_FILES['image'])) {
					$name = time() . "." . end(explode(".", $_FILES['image']['name']));
					move_uploaded_file($_FILES['image']['tmp_name'], $this->plugins_path . '/images/' . $name);
					echo json_encode(array("name" => $name, "src" => $this->plugins_url . '/images/' . $name));
					die();
				}
			}

			public function gift_meta_boxe_animation($gift) {
				$animation = get_post_meta($gift->ID, 'gift_image_animation', true);
				if( giftmachine_is_pro() ) {
			        $animations = array(
			            array("name" => "Bounce", "class" => "animate__animated animate__bounce animate__infinite"),
			            array("name" => "Flash", "class" => "animate__animated animate__flash animate__infinite"),
			            array("name" => "Pulse", "class" => "animate__animated animate__pulse animate__infinite"),
			            array("name" => "Rubber Band", "class" => "animate__animated animate__rubberBand animate__infinite"),
			            array("name" => "Shake X", "class" => "animate__animated animate__shakeX animate__infinite"),
			            array("name" => "Shake Y", "class" => "animate__animated animate__shakeY animate__infinite"),
			            array("name" => "Head Shake", "class" => "animate__animated animate__headShake animate__infinite"),
			            array("name" => "Swing", "class" => "animate__animated animate__swing animate__infinite"),
			            array("name" => "Tada", "class" => "animate__animated animate__tada animate__infinite"),
			            array("name" => "Wobble", "class" => "animate__animated animate__wobble animate__infinite"),
			            array("name" => "Jello", "class" => "animate__animated animate__jello animate__infinite"),
			            array("name" => "Heart Beat", "class" => "animate__animated animate__heartBeat animate__infinite"),
			        );
			    }
			    else {
			    	$animations = array(
			    	    array("name" => "Bounce", "class" => "animate__animated animate__bounce animate__infinite"),
			    	    array("name" => "Flash", "class" => "animate__animated animate__flash animate__infinite"),
			    	    array("name" => "Pulse", "class" => "animate__animated animate__pulse animate__infinite"));
			    }
				echo '<p>Select animation style for gift icon</p>';
				echo '<select name="gift_image_animation">';
        foreach ($animations as $anim) {
            echo '<option value="'.$anim['class'].'" '.($animation == $anim['class'] ? "selected=selected" : "").'>'.$anim['name'].'</option>';
        }
				echo '</select>';
			}

			public function gift_meta_autoresponder( $gift ) {
				giftmachine_autoresponder_select( $gift->ID );
			}

			public function gift_meta_visibility($gift) {
				$fields = explode(",", get_post_meta($gift->ID, 'gift_popup_visibility', true));
				$hide_mobile = get_post_meta( $gift->ID, '_hide_mobile', true );
				echo '<p>Select visibility for this gift</p>';
				echo '
					<div class="visibility_option">
						<label>
							<input type="checkbox" name="gift_popup_visibility[]" id="gift_popup_visibility" value="entire" '.(in_array("entire", $fields) ? "checked=checked" : "").' /> Entire Site
						</label>
					</div>
					<div class="visibility_option">
						<label>
							<input type="checkbox" name="gift_popup_visibility[]" value="homepage" '.(in_array("homepage", $fields) ? "checked=checked" : "").' /> Homepage
						</label>
					</div>';
				if( giftmachine_is_pro() ) {
					echo '<div class="visibility_option">
						<label>
							<input type="checkbox" name="gift_popup_visibility[]" value="category" '.(in_array("category", $fields) ? "checked=checked" : "").' /> Category Pages
						</label>
					</div>
					<div class="visibility_option">
						<label>
							<input type="checkbox" name="gift_popup_visibility[]" value="posts" '.(in_array("posts", $fields) ? "checked=checked" : "").' /> All Posts
						</label>
					</div>
					<div class="visibility_option">
						<label>
							<input type="checkbox" name="gift_popup_visibility[]" value="pages" '.(in_array("pages", $fields) ? "checked=checked" : "").' /> All Pages
						</label>
					</div>
				';
				}
				echo '	<div style="clear: both"> </div>';

				if( giftmachine_is_pro() ) {
					echo '<hr/>';
					echo '<div class="visibility_option">
						<label>
							<input type="checkbox" name="gift_hide_mobile" value="1" '.( $hide_mobile ? "checked=checked" : "").' /> Hide on Mobile
						</label>
					</div><br/><p><small>If you check this, the gift will not show on mobile devices</small></p>';
					echo '<hr/>';
					$start = trim( get_post_meta( $gift->ID, '_gift_start', true ) );
					$end = trim( get_post_meta( $gift->ID, '_gift_end', true ) );

					echo '<h4>Schedule Campaign</h4>';
					echo '<p>You can select a start/end date for this campaign</p>
					<label for="gift-start-date">Start Date</label>
					<input type="text" id="gift-start-date" value="'.$start.'" name="gift-start-date" class="gift-date" style="margin-left: 5px"/>
					<br/><br/>
					<label for="gift-end-date">End Date &nbsp;</label>
					<input type="text" id="gift-end-date" name="gift-end-date" value="'.$end.'" class="gift-date" style="margin-left: 3px"/>
					<p><small>Date Format: yyyy-mm-dd</small>
					';
				}
					echo '	<div style="clear: both"> </div>';
			}

			public function gift_meta_box_type($gift) {
				$gifts = get_posts( array('numberposts' => -1, 'post_status' => 'any', 'post_type' => $this->type) );
				$exids = array();

				foreach ($gifts as $gift)
					$exids[] = $gift->ID;

				$posts = get_posts( array('numberposts' => -1, 'post_status' => 'publish', 'exclude' => $exids, 'post_type' => get_post_types('', 'names')) );

				echo '<p>Select Post(s) on which you want to show this gift</p>';
				if (count($posts) > 0) {
					echo '<select name="gift_posts" multiple class="regular-text">';
					foreach ($posts as $post) {
						echo '<option value="'.$post->ID.'" title="'.$post->post_title.'">'.$post->post_title.'</option>';
					}
					echo '</select>';
				}
				else
					echo '<p>You do not have any post published yet!</p>';

				echo '<p> </p><hr>';

				echo '<p>Select Page(s) on which you want to show this gift!</p>';
				$pages = get_pages(array("post_type" => 'page', 'post_status' => 'publish'));
				if (count($pages) > 0) {
					echo '<select name="gift_pages" multiple class="regular-text">';
					foreach ($pages as $page) {
						echo '<option value="'.$page->ID.'" title="'.$page->post_title.'">'.$page->post_title.'</option>';
					}
					echo '</select>';
				}
				else
					echo '<p>You do not have any page published yet!</p>';

				echo '<p> </p><hr>';

				echo '<p>Do you want to show it on all pages of website? <input type="checkbox" value="1" name="gift_everywhere" class="regular-text" /></p>';

				echo '<style>option { padding: 2%; }</style>';
			}

			public function gift_meta_box_seconds($gift) {
				$gift_popup_sec = get_post_meta($gift->ID, 'gift_popup_sec', true);
				echo '
					<p>Specify the number of <b>seconds</b> after which icon will be displayed.</p>
					<input type="text" name="gift_popup_sec" value="'.$gift_popup_sec.'" />';
			}

			public function gift_meta_box_url($gift) {
				$gift_popup_url = get_post_meta($gift->ID, 'gift_popup_url', true);
				echo '
					<p>This is the page URL where your visitor will be sent after entering his email and you can deliver your gift on this page URL...</p>
					<table class="form-table">
						<tbody>
							<tr>
								<th scope="row"><label>Enter the Page URL </label></th>
								<td><input type="text" name="gift_popup_url" class="regular-text" value="'.$gift_popup_url.'" /></td>
							</tr>
						</tbody>
					</table>';
			}

			public function pr($var) {
				echo 'Data: <pre>';
				print_r($var);
				die();
			}
		}
	}

	global $gift;
	$gift = new GiftMachinePRO();

	require GIFTMACHINE_DIR.'/lib/plugin-update-checker/plugin-update-checker.php';
	$puchcker = new Puc_v4p10_Plugin_UpdateChecker(
	    ( giftmachine_is_pro() ? 'https://knighterrant.s3.us-west-2.amazonaws.com/software/gift-machine/2-pro/info_wpbp2.json' : 'https://knighterrant.s3.us-west-2.amazonaws.com/software/gift-machine/1-fe/info_wpbp1.json' ),
	    GIFTMACHINE_DIR.GIFTMACHINE_PLUGIN_NAME.'.php'
	);

	// require 'plugin-update-checker/plugin-update-checker.php';

	// $myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	//     'http://kreateplugins.com/update/GiftMachinePRO.json',
	//     __FILE__, //Full path to the main plugin file or functions.php.
	//     'AutoLoader'
	// );
?>